#!/bin/sh

echo ""
echo "        nc_bymonth.sh  Version 1.0"
echo "        Written by Arne Melsom"
echo "           a.melsom@dnmi.no"
echo "            (+47) 2296 3316"
echo "           October 19, 2001"
echo ""


# Check syntax:
###############

if [ "$2" = "" ]
then
    echo ">>>   SYNTAX ERROR   <<<"
    echo ""
    echo ">>> nc_bymonth.sh outputs the mean monthly values from a set of"
    echo ">>>                   files to a designated month-by-month file."
    echo ""
    echo ">>> Format:"
    echo ">>>  nc_bymonth.sh /filelist/ /variable/" 
    echo ">>> where"
    echo ">>>   /file_list/    is the name of a file that contains"
    echo ">>>                   * no. of file names on line 1"
    echo ">>>                   * list of input file names on following lines"
    echo ">>>                   * output file name on the final line"
    echo ">>>   /variable/     is the name of the variable for which"
    echo ">>>                   monthly output will be produced."
    echo ""
    echo ">>> Script terminates."
    echo ""
    exit
fi


# Read command line argumnts:
#############################

filelist=$1
vrbl_name=$2


# Require non-existing flag file:
#################################

test -r ok_flag && echo ">>> Flag file exists!"
test -r ok_flag && echo ">>> Script terminates prematurely."
test -r ok_flag && echo ""
test -r ok_flag && exit


# Compile "nc_dims" if necessary:
#################################

test -r nc_dims || /usr/bin/make -f nc_dims.make
test -r nc_dims || echo ">>> Compilation of 'nc_dims' failed."
test -r nc_dims || echo ">>> Script terminates."
test -r nc_dims || echo ""
test -r nc_dims || exit


# Run "nc_dims":
################

./nc_dims <$filelist
test -r ok_flag || echo ">>> Execution of 'nc_dims' failed."
test -r ok_flag || echo ">>> Script terminates."
test -r ok_flag || echo ""
test -r ok_flag || exit
/bin/rm ok_flag


# (Re-)Compile "nc_bymonth":
################################

test -r nc_bymonth && /bin/rm nc_bymonth
/usr/bin/make -f nc_bymonth.make
/bin/rm *.o
test -r nc_bymonth || echo ">>> Compilation of 'nc_bymonth' failed!"
test -r nc_bymonth || echo ">>> Script terminates prematurely."
test -r nc_bymonth || echo ""
test -r nc_bymonth || exit


# Run "nc_bymonth":
#######################

./nc_bymonth $vrbl_name <$filelist
test -r ok_flag || echo ">>> Execution of 'nc_bymonth' failed!"
test -r ok_flag || echo ">>> Script terminates prematurely."
test -r ok_flag || echo ""
test -r ok_flag || exit
/bin/rm ok_flag

exit
